/* comt_smb.h 29.01.2002 Stefan Pfingstner / Comtarsia IT Services
			  18.02.2002 Stefan Pfingstner / added support for OS/2 shares and apps 
			  21.03.2002 Stefan Pfingstner / added chgpwd 
			  23.03.2002 Stefan Pfingstner / changed the user_app_info_2 struct
			  22.08.2002 Stefan Pfingstner / changed the pragma pack				*/

#ifndef _COMT_SMB_H_
#define _COMT_SMB_H_

#pragma pack(push, 1)

#include "..\comt_versions.h"
//#define COMT_SMB_VERSION	7

#define LS_SUCCESS			0	/* supplied user/password combination is valid */
#define LS_WRONG_PASSWORD	1	/* wrong password or user unknown */
#define LS_PASSWORD_EXPIRED	2	/* password is expired */
#define LS_NO_RESPONSE		3	/* no response from lanserver */
#define LS_ERROR			4	/* general error */
#define LS_BUSY				5	/* another ls-call is in progresss; retry in a few seconds */
#define LS_LOCAL			6	/* user is locally logged on */

/* Lan Manager constants */
#define LM_SHARE_TYPE_DIR			1		/* share is a directory share */
#define LM_SHARE_TYPE_PRT			2		/* share is a printer share */

/* constants for the log functions */
#define LOG_ERROR	1		/* log-message type is error */
#define LOG_DEBUG	5		/* log-message type is debug */


/* generic share info */
typedef struct _user_share_info_1
{
	char			share_alias[10];		/* os/2 share alias	*/
	unsigned short	share_type;				/* type of share: LM_SHARE_TYPE_DIR or 
												LM_SHARE_TYPE_PRT */
	char			share_local_port[9];	/* port of the client os, which should be
												used for this device 
												for Directories:	* = any drive letter
																	X = use thos drive letter 
												for Printer:		LPTX = lpt for printer */
} user_share_info_1;

/* extended share info */
typedef struct _user_share_info_2
{
	char			share_alias[10];		/* os/2 share alias */
	char			share_server[17];		/* share server */
	char			share_remote_device[14];/* device name of the printer on the server, not 
												used for directories */
	char			share_remote_path[255];	/* logical path of the share on the os/2 server */
	char			share_desc[255];		/* Description of the share */
} user_share_info_2;


/* generic application info */
typedef struct _user_app_info_1
{
	char			app_name[10];			/* Applikation name */
	unsigned short	app_type;				/* 1 for Windows apps */
	unsigned short	pad_bytes;				/* ignored */
} user_app_info_1;

/* extended application info */
typedef struct _user_app_info_2
{
	char	app_name[10];					/* Applikation name */
	char	app_program_location[10];		/* Share "Program location" */
	char	app_program_location_drive;		/* Program Location Assigned Drive */
	char	app_pl_remaining_path[255];		/* Program Location remaining path */
	char	app_working_dir[10];			/* Share 1 "Working Directory" */
	char	app_working_dir_drive;			/* Working Directory Assigned Drive */
	char	app_wd_remaining_path[255];		/* Working Directory remaining path */
	char	cmd_parameters[255];			/* Command Parameters */
	char	app_cmd[255];					/* inclusive absolute path */
	char	app_desc[255];					/* Application description */
	char	prompt_for_additional_params;	/* Prompt for additional Parameters */
} user_app_info_2;


/* returns the version number of the comt_smb.dll file */
__declspec(dllexport) int smb_get_version();

/* checks the supplied user/password combination against an OS/2 lanserver 
	char *UserName	[in] 16 bytes buffer to a 0 terminated string 
	char *PassWord	[in] 16 bytes buffer to a 0 terminated string 
	returns != LS_SUCCESS on error											*/
__declspec(dllexport) int smb_chklspwd(char *UserName, char *PassWord);


/* checks the supplied user/password combination against an OS/2 lanserver 
	char *UserName	[in] 16 bytes buffer to a 0 terminated string 
	char *PassWord	[in] 16 bytes buffer to a 0 terminated string 
	char *SrvName0	[in] 16 bytes buffer to a 0 terminated string 
	char *Domain	[in] 16 bytes buffer to a 0 terminated string 
	returns != LS_SUCCESS on error											*/
__declspec(dllexport) int smb_chklspwd_ext(char *UserName, char *PassWord,
										   char *SrvName0, char *Domain,
										   void *shMem);

/* returns available directory and printer shares for a specific user
	If shmem is not supplied the shared memory is opened by the dll.
	If you call this function from the same process as the shared mem 
	is created you have to supply a shMem pointer, because opening the
	shared mem in the dll will fail										*/
__declspec(dllexport) int smb_ls_sharesinfo(char *UserName, char *PassWord, 
											char *rbuf_1, int *rbuf_1_len,
											char *rbuf_2, int *rbuf_2_len,
											void *shMem);

/* returns available user applications
	If shmem is not supplied the shared memory is opened by the dll.
	If you call this function from the same process as the shared mem 
	is created you have to supply a shMem pointer, because opening the
	shared mem in the dll will fail										*/
__declspec(dllexport) int smb_ls_appsinfo(char *UserName, char *PassWord, 
										  char *rbuf_1, int *rbuf_1_len, 
										  char *rbuf_2, int *rbuf_2_len,
										  void *shMem);

/* changes the password on the lanserver 
	If shmem is not supplied the shared memory is opened by the dll.
	If you call this function from the same process as the shared mem 
	is created you have to supply a shMem pointer, because opening the
	shared mem in the dll will fail										*/
__declspec(dllexport) int smb_ls_chgpwd(char* WkstName, char* SrvName0,
										char* Domain, char* UserName, 
										char* oldPassWord, char *newPassWord,
										void *shMem);

#pragma pack(pop)

#endif